@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.51'; # VERSION
+our $DATE = '2017-01-01'; # DATE
+our $VERSION = '0.52'; # VERSION
 
 use 5.010001;
 use strict;
@@ -346,7 +346,7 @@ sub lint_prereqs {
             $assume_provided{$phase}{$mod} = $v if     $section =~ /assume-provided/;
             $assume_used{$phase}{$mod}     = $v if     $section =~ /assume-used/ ||
                 $dir_s =~ /^lint[_-]prereqs\s+assume-used\b/m ||
-                $rel =~ /\A(X_spec|X_copypaste)\z/;
+                $rel =~ /\A(X_spec|X_alt_for|X_copypaste)\z/;
         } # for param
     } # for section
     _create_prereqs_for_Any_phase(\%mods_from_ini);
@@ -675,7 +675,7 @@ App::LintPrereqs - Check extraneous/missing/incorrect prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.51 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-12-28.
+This document describes version 0.52 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-01-01.
 
 =head1 SYNOPSIS
 
@@ -817,7 +817,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
